.. module:: tests.scorekeeper

***********
scorekeeper
***********

This module provides functions used to by :py:class:`pytest` to run tests against
the following objects:

- :py:class:`wwdtm.scorekeeper.Scorekeeper`
- :py:class:`wwdtm.scorekeeper.ScorekeeperAppearances`
- :py:class:`wwdtm.scorekeeper.ScorekeeperUtility`

test_scorekeeper_appearances
============================

.. automodule:: tests.scorekeeper.test_scorekeeper_appearances
    :members:
    :undoc-members:

test_scorekeeper_scorekeeper
============================

.. automodule:: tests.scorekeeper.test_scorekeeper_scorekeeper
    :members:
    :undoc-members:

test_scorekeeper_utility
========================

.. automodule:: tests.scorekeeper.test_scorekeeper_utility
    :members:
    :undoc-members:
